/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2004 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
*/

#ifndef _SDL_direct3dcommon_h
#define _SDL_direct3dcommon_h

#define CINTERFACE

#include "SDL.h"
#include "../windib/SDL_dibevents_c.h"
#include "SDL_sysmouse_c.h"
#include "SDL_sysvideo.h"
#include "SDL_syswm_c.h"

#include "SDL_direct3dext.h"

/* Direct3D & Windows includes */
#define WIN32_LEAN_AND_MEAN		// Exclude rarely-used stuff from Windows headers
#include <d3d9.h>
#include <dxerr9.h>

#ifndef _FACD3D
#define _FACD3D 0x876
#endif

#ifndef _FACDD
#define _FACDD 0x876
#endif


/* Error handling */
const char * ConvertHresultToString(HRESULT result);

#define VERIFY_FCALL(FUNCTION_NAME, PARAMS, ON_ERROR) \
	{ \
		HRESULT _fcall_hresult = FUNCTION_NAME PARAMS; \
		if ( FAILED(_fcall_hresult) ) { \
			SDL_SetError("%s failed: %s", #FUNCTION_NAME, ConvertHresultToString(_fcall_hresult)); \
			ON_ERROR; \
		} \
	}

/* Creates a custom HRESULT.  A severity of 0 indicates success, while 1
   indicates failure.  Codes passed to this macro may start at 0. */
#define MAKE_SDLD3D_HRESULT(severity, code) \
	MAKE_HRESULT(severity, FACILITY_ITF, (code + 0x300))

/* Custom HRESULTS */
#define SDLD3DERR_INVALIDPARAMS				MAKE_SDLD3D_HRESULT(1, 0x0)

#endif
